@@ -29,9 +29,9 @@ use frida_gum::{Gum, ModuleMap};
 use libc::RLIMIT_STACK;
 #[cfg(target_arch = "aarch64")]
 use libc::{c_char, wchar_t};
-#[cfg(any(target_os = "macos", target_os = "ios"))]
+#[cfg(target_vendor = "apple")]
 use libc::{getrlimit, rlimit};
-#[cfg(all(unix, not(any(target_os = "macos", target_os = "ios"))))]
+#[cfg(all(unix, not(target_vendor = "apple")))]
 use libc::{getrlimit64, rlimit64};
 use std::{ffi::c_void, ptr::write_volatile};
 
@@ -50,9 +50,9 @@ extern "C" {
     fn tls_ptr() -> *const c_void;
 }
 
-#[cfg(any(target_os = "macos", target_os = "ios"))]
+#[cfg(target_vendor = "apple")]
 const ANONYMOUS_FLAG: MapFlags = MapFlags::MAP_ANON;
-#[cfg(not(any(target_os = "macos", target_os = "ios")))]
+#[cfg(not(target_vendor = "apple"))]
 const ANONYMOUS_FLAG: MapFlags = MapFlags::MAP_ANONYMOUS;
 
 /// The frida address sanitizer runtime, providing address sanitization.
@@ -210,7 +210,7 @@ impl AsanRuntime {
 
     /// Get the maximum stack size for the current stack
     #[must_use]
-    #[cfg(any(target_os = "macos", target_os = "ios"))]
+    #[cfg(target_vendor = "apple")]
     fn max_stack_size() -> usize {
         let mut stack_rlimit = rlimit {
             rlim_cur: 0,
@@ -223,7 +223,7 @@ impl AsanRuntime {
 
     /// Get the maximum stack size for the current stack
     #[must_use]
-    #[cfg(all(unix, not(any(target_os = "macos", target_os = "ios"))))]
+    #[cfg(all(unix, not(target_vendor = "apple")))]
     fn max_stack_size() -> usize {
         let mut stack_rlimit = rlimit64 {
             rlim_cur: 0,
@@ -254,7 +254,7 @@ impl AsanRuntime {
         let max_start = end - Self::max_stack_size();
 
         let flags = ANONYMOUS_FLAG | MapFlags::MAP_FIXED | MapFlags::MAP_PRIVATE;
-        #[cfg(not(any(target_os = "macos", target_os = "ios")))]
+        #[cfg(not(target_vendor = "apple"))]
         let flags = flags | MapFlags::MAP_STACK;
 
         if start != max_start {
@@ -399,7 +399,7 @@ impl AsanRuntime {
         }
     }
 
-    #[cfg(all(target_arch = "aarch64", not(target_os = "macos")))]
+    #[cfg(all(target_arch = "aarch64", not(target_vendor = "apple")))]
     #[inline]
     fn hook_memalign(&mut self, alignment: usize, size: usize) -> *mut c_void {
         unsafe { self.allocator.alloc(size, alignment) }
@@ -420,7 +420,7 @@ impl AsanRuntime {
     }
 
     #[inline]
-    #[cfg(all(target_arch = "aarch64", not(target_os = "macos")))]
+    #[cfg(all(target_arch = "aarch64", not(target_vendor = "apple")))]
     fn hook_malloc_usable_size(&mut self, ptr: *mut c_void) -> usize {
         self.allocator.get_usable_size(ptr)
     }
@@ -708,7 +708,7 @@ impl AsanRuntime {
     }
 
     #[inline]
-    #[cfg(all(target_arch = "aarch64", not(target_os = "macos")))]
+    #[cfg(all(target_arch = "aarch64", not(target_vendor = "apple")))]
     fn hook_mempcpy(&mut self, dest: *mut c_void, src: *const c_void, n: usize) -> *mut c_void {
         extern "C" {
             fn mempcpy(dest: *mut c_void, src: *const c_void, n: usize) -> *mut c_void;
@@ -810,7 +810,7 @@ impl AsanRuntime {
     }
 
     #[inline]
-    #[cfg(all(target_arch = "aarch64", not(target_os = "macos")))]
+    #[cfg(all(target_arch = "aarch64", not(target_vendor = "apple")))]
     fn hook_memrchr(&mut self, s: *mut c_void, c: i32, n: usize) -> *mut c_void {
         extern "C" {
             fn memrchr(s: *mut c_void, c: i32, n: usize) -> *mut c_void;
@@ -894,7 +894,7 @@ impl AsanRuntime {
     #[cfg(all(
         not(target_os = "android"),
         target_arch = "aarch64",
-        not(target_os = "macos")
+        not(target_vendor = "apple")
     ))]
     #[inline]
     fn hook_explicit_bzero(&mut self, s: *mut c_void, n: usize) {
@@ -1594,7 +1594,7 @@ impl AsanRuntime {
         hook_func!(None, calloc, (nmemb: usize, size: usize), *mut c_void);
         hook_func!(None, realloc, (ptr: *mut c_void, size: usize), *mut c_void);
         hook_func_with_check!(None, free, (ptr: *mut c_void), ());
-        #[cfg(not(target_os = "macos"))]
+        #[cfg(not(target_vendor = "apple"))]
         hook_func!(None, memalign, (size: usize, alignment: usize), *mut c_void);
         hook_func!(
             None,
@@ -1602,7 +1602,7 @@ impl AsanRuntime {
             (pptr: *mut *mut c_void, size: usize, alignment: usize),
             i32
         );
-        #[cfg(not(target_os = "macos"))]
+        #[cfg(not(target_vendor = "apple"))]
         hook_func!(None, malloc_usable_size, (ptr: *mut c_void), usize);
         hook_func!(None, _Znam, (size: usize), *mut c_void);
         hook_func!(
@@ -1736,7 +1736,7 @@ impl AsanRuntime {
             (dest: *mut c_void, src: *const c_void, n: usize),
             *mut c_void
         );
-        #[cfg(not(target_os = "macos"))]
+        #[cfg(not(target_vendor = "apple"))]
         hook_func!(
             None,
             mempcpy,
@@ -1761,7 +1761,7 @@ impl AsanRuntime {
             (s: *mut c_void, c: i32, n: usize),
             *mut c_void
         );
-        #[cfg(not(target_os = "macos"))]
+        #[cfg(not(target_vendor = "apple"))]
         hook_func!(
             None,
             memrchr,
@@ -1781,7 +1781,7 @@ impl AsanRuntime {
         );
         #[cfg(not(target_os = "android"))]
         hook_func!(None, bzero, (s: *mut c_void, n: usize), ());
-        #[cfg(not(any(target_os = "macos", target_os = "android")))]
+        #[cfg(not(any(target_os = "android", target_vendor = "apple")))]
         hook_func!(None, explicit_bzero, (s: *mut c_void, n: usize), ());
         #[cfg(not(target_os = "android"))]
         hook_func!(
